# -*- coding: utf-8 -*-

from akagi.data_files import s3_data_file
from akagi.data_files import local_data_file

from akagi.data_files.s3_data_file import S3DataFile
from akagi.data_files.local_data_file import LocalDataFile
